# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '.\ressources\QT_ui\MainWindow.ui'
#
# Created by: PyQt5 UI code generator 5.15.10
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_IACOB(object):
    def setupUi(self, IACOB):
        IACOB.setObjectName("IACOB")
        IACOB.resize(1736, 976)
        self.centralWidget = QtWidgets.QWidget(IACOB)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.centralWidget.sizePolicy().hasHeightForWidth())
        self.centralWidget.setSizePolicy(sizePolicy)
        self.centralWidget.setObjectName("centralWidget")
        self.gridLayout_9 = QtWidgets.QGridLayout(self.centralWidget)
        self.gridLayout_9.setObjectName("gridLayout_9")
        self.mainTabWidget = QtWidgets.QTabWidget(self.centralWidget)
        self.mainTabWidget.setTabPosition(QtWidgets.QTabWidget.North)
        self.mainTabWidget.setObjectName("mainTabWidget")
        self.tab1FileInfo_widget = QtWidgets.QWidget()
        self.tab1FileInfo_widget.setObjectName("tab1FileInfo_widget")
        self.gridLayout = QtWidgets.QGridLayout(self.tab1FileInfo_widget)
        self.gridLayout.setObjectName("gridLayout")
        self.fileInfosSupport_Frame = QtWidgets.QFrame(self.tab1FileInfo_widget)
        self.fileInfosSupport_Frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.fileInfosSupport_Frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.fileInfosSupport_Frame.setObjectName("fileInfosSupport_Frame")
        self.gridLayout_19 = QtWidgets.QGridLayout(self.fileInfosSupport_Frame)
        self.gridLayout_19.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_19.setObjectName("gridLayout_19")
        self.informationsSection_Widget = QtWidgets.QFrame(self.fileInfosSupport_Frame)
        self.informationsSection_Widget.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.informationsSection_Widget.setFrameShadow(QtWidgets.QFrame.Raised)
        self.informationsSection_Widget.setObjectName("informationsSection_Widget")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.informationsSection_Widget)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.openedFiles_Widget = QtWidgets.QWidget(self.informationsSection_Widget)
        self.openedFiles_Widget.setObjectName("openedFiles_Widget")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.openedFiles_Widget)
        self.horizontalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.openedFiles_Label = QtWidgets.QLabel(self.openedFiles_Widget)
        self.openedFiles_Label.setObjectName("openedFiles_Label")
        self.horizontalLayout_2.addWidget(self.openedFiles_Label)
        self.openedDataFile_Label = QtWidgets.QLabel(self.openedFiles_Widget)
        self.openedDataFile_Label.setObjectName("openedDataFile_Label")
        self.horizontalLayout_2.addWidget(self.openedDataFile_Label)
        self.currentDataFile_Label = QtWidgets.QLabel(self.openedFiles_Widget)
        self.currentDataFile_Label.setText("")
        self.currentDataFile_Label.setObjectName("currentDataFile_Label")
        self.horizontalLayout_2.addWidget(self.currentDataFile_Label)
        self.openedFlutFile_Label = QtWidgets.QLabel(self.openedFiles_Widget)
        self.openedFlutFile_Label.setObjectName("openedFlutFile_Label")
        self.horizontalLayout_2.addWidget(self.openedFlutFile_Label)
        self.currentFlutFile_Label = QtWidgets.QLabel(self.openedFiles_Widget)
        self.currentFlutFile_Label.setText("")
        self.currentFlutFile_Label.setObjectName("currentFlutFile_Label")
        self.horizontalLayout_2.addWidget(self.currentFlutFile_Label)
        self.horizontalLayout_2.setStretch(0, 2)
        self.horizontalLayout_2.setStretch(1, 1)
        self.horizontalLayout_2.setStretch(2, 4)
        self.horizontalLayout_2.setStretch(3, 1)
        self.horizontalLayout_2.setStretch(4, 4)
        self.verticalLayout_3.addWidget(self.openedFiles_Widget)
        self.fileInformations_Widget = QtWidgets.QWidget(self.informationsSection_Widget)
        self.fileInformations_Widget.setObjectName("fileInformations_Widget")
        self.gridLayout_18 = QtWidgets.QGridLayout(self.fileInformations_Widget)
        self.gridLayout_18.setSizeConstraint(QtWidgets.QLayout.SetDefaultConstraint)
        self.gridLayout_18.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_18.setObjectName("gridLayout_18")
        self.nbNodesValue_Label = QtWidgets.QLabel(self.fileInformations_Widget)
        self.nbNodesValue_Label.setText("")
        self.nbNodesValue_Label.setObjectName("nbNodesValue_Label")
        self.gridLayout_18.addWidget(self.nbNodesValue_Label, 0, 2, 1, 1)
        self.nbNodes_Label = QtWidgets.QLabel(self.fileInformations_Widget)
        self.nbNodes_Label.setObjectName("nbNodes_Label")
        self.gridLayout_18.addWidget(self.nbNodes_Label, 0, 0, 1, 1)
        self.nbConnections_Label = QtWidgets.QLabel(self.fileInformations_Widget)
        self.nbConnections_Label.setObjectName("nbConnections_Label")
        self.gridLayout_18.addWidget(self.nbConnections_Label, 1, 0, 1, 1)
        self.sumAbsValue_Label = QtWidgets.QLabel(self.fileInformations_Widget)
        self.sumAbsValue_Label.setText("")
        self.sumAbsValue_Label.setObjectName("sumAbsValue_Label")
        self.gridLayout_18.addWidget(self.sumAbsValue_Label, 0, 4, 1, 1)
        self.standardDeviation_Label = QtWidgets.QLabel(self.fileInformations_Widget)
        self.standardDeviation_Label.setObjectName("standardDeviation_Label")
        self.gridLayout_18.addWidget(self.standardDeviation_Label, 0, 9, 1, 1)
        self.max_Label = QtWidgets.QLabel(self.fileInformations_Widget)
        self.max_Label.setObjectName("max_Label")
        self.gridLayout_18.addWidget(self.max_Label, 0, 5, 1, 1)
        self.standardDeviationValue_Label = QtWidgets.QLabel(self.fileInformations_Widget)
        self.standardDeviationValue_Label.setText("")
        self.standardDeviationValue_Label.setObjectName("standardDeviationValue_Label")
        self.gridLayout_18.addWidget(self.standardDeviationValue_Label, 0, 10, 1, 1)
        self.sumAbs_Label = QtWidgets.QLabel(self.fileInformations_Widget)
        self.sumAbs_Label.setObjectName("sumAbs_Label")
        self.gridLayout_18.addWidget(self.sumAbs_Label, 0, 3, 1, 1)
        self.nbConnectionsValue_Label = QtWidgets.QLabel(self.fileInformations_Widget)
        self.nbConnectionsValue_Label.setText("")
        self.nbConnectionsValue_Label.setObjectName("nbConnectionsValue_Label")
        self.gridLayout_18.addWidget(self.nbConnectionsValue_Label, 1, 2, 1, 1)
        self.meanAbsValue_Label = QtWidgets.QLabel(self.fileInformations_Widget)
        self.meanAbsValue_Label.setText("")
        self.meanAbsValue_Label.setObjectName("meanAbsValue_Label")
        self.gridLayout_18.addWidget(self.meanAbsValue_Label, 1, 4, 1, 1)
        self.maxValue_Label = QtWidgets.QLabel(self.fileInformations_Widget)
        self.maxValue_Label.setText("")
        self.maxValue_Label.setObjectName("maxValue_Label")
        self.gridLayout_18.addWidget(self.maxValue_Label, 0, 6, 1, 1)
        self.meanAbs_Label = QtWidgets.QLabel(self.fileInformations_Widget)
        self.meanAbs_Label.setObjectName("meanAbs_Label")
        self.gridLayout_18.addWidget(self.meanAbs_Label, 1, 3, 1, 1)
        self.thresholdValue_Label = QtWidgets.QLabel(self.fileInformations_Widget)
        self.thresholdValue_Label.setText("")
        self.thresholdValue_Label.setObjectName("thresholdValue_Label")
        self.gridLayout_18.addWidget(self.thresholdValue_Label, 1, 10, 1, 1)
        self.minValue_Label = QtWidgets.QLabel(self.fileInformations_Widget)
        self.minValue_Label.setText("")
        self.minValue_Label.setObjectName("minValue_Label")
        self.gridLayout_18.addWidget(self.minValue_Label, 1, 6, 1, 1)
        self.min_Label = QtWidgets.QLabel(self.fileInformations_Widget)
        self.min_Label.setObjectName("min_Label")
        self.gridLayout_18.addWidget(self.min_Label, 1, 5, 1, 1)
        self.threshold_Label = QtWidgets.QLabel(self.fileInformations_Widget)
        self.threshold_Label.setObjectName("threshold_Label")
        self.gridLayout_18.addWidget(self.threshold_Label, 1, 9, 1, 1)
        self.maxRelValue_Label = QtWidgets.QLabel(self.fileInformations_Widget)
        self.maxRelValue_Label.setText("")
        self.maxRelValue_Label.setObjectName("maxRelValue_Label")
        self.gridLayout_18.addWidget(self.maxRelValue_Label, 0, 8, 1, 1)
        self.minRel_Label = QtWidgets.QLabel(self.fileInformations_Widget)
        self.minRel_Label.setObjectName("minRel_Label")
        self.gridLayout_18.addWidget(self.minRel_Label, 0, 7, 1, 1)
        self.maxRel_Label = QtWidgets.QLabel(self.fileInformations_Widget)
        self.maxRel_Label.setObjectName("maxRel_Label")
        self.gridLayout_18.addWidget(self.maxRel_Label, 1, 7, 1, 1)
        self.minRelValue_Label = QtWidgets.QLabel(self.fileInformations_Widget)
        self.minRelValue_Label.setText("")
        self.minRelValue_Label.setObjectName("minRelValue_Label")
        self.gridLayout_18.addWidget(self.minRelValue_Label, 1, 8, 1, 1)
        self.verticalLayout_3.addWidget(self.fileInformations_Widget)
        self.verticalLayout_3.setStretch(0, 1)
        self.verticalLayout_3.setStretch(1, 2)
        self.gridLayout_19.addWidget(self.informationsSection_Widget, 0, 0, 1, 1)
        self.graphSection_Widget = QtWidgets.QWidget(self.fileInfosSupport_Frame)
        self.graphSection_Widget.setObjectName("graphSection_Widget")
        self.gridLayout_17 = QtWidgets.QGridLayout(self.graphSection_Widget)
        self.gridLayout_17.setObjectName("gridLayout_17")
        self.graphDisplay_Layout = QtWidgets.QGridLayout()
        self.graphDisplay_Layout.setObjectName("graphDisplay_Layout")
        self.gridLayout_17.addLayout(self.graphDisplay_Layout, 0, 0, 1, 1)
        self.gridLayout_19.addWidget(self.graphSection_Widget, 1, 0, 1, 1)
        self.gridLayout_19.setRowStretch(0, 1)
        self.gridLayout_19.setRowStretch(1, 5)
        self.gridLayout.addWidget(self.fileInfosSupport_Frame, 0, 0, 1, 1)
        self.noInfoTab1_Label = QtWidgets.QLabel(self.tab1FileInfo_widget)
        self.noInfoTab1_Label.setObjectName("noInfoTab1_Label")
        self.gridLayout.addWidget(self.noInfoTab1_Label, 1, 0, 1, 1)
        self.mainTabWidget.addTab(self.tab1FileInfo_widget, "")
        self.tab2Circular_widget = QtWidgets.QWidget()
        self.tab2Circular_widget.setObjectName("tab2Circular_widget")
        self.gridLayout_5 = QtWidgets.QGridLayout(self.tab2Circular_widget)
        self.gridLayout_5.setObjectName("gridLayout_5")
        self.circularTabSupport_Frame = QtWidgets.QFrame(self.tab2Circular_widget)
        self.circularTabSupport_Frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.circularTabSupport_Frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.circularTabSupport_Frame.setObjectName("circularTabSupport_Frame")
        self.gridLayout_16 = QtWidgets.QGridLayout(self.circularTabSupport_Frame)
        self.gridLayout_16.setObjectName("gridLayout_16")
        self.gridLayout_5.addWidget(self.circularTabSupport_Frame, 0, 0, 1, 1)
        self.noInfoTab2_Label = QtWidgets.QLabel(self.tab2Circular_widget)
        self.noInfoTab2_Label.setObjectName("noInfoTab2_Label")
        self.gridLayout_5.addWidget(self.noInfoTab2_Label, 1, 0, 1, 1)
        self.mainTabWidget.addTab(self.tab2Circular_widget, "")
        self.tab3Pie_widget = QtWidgets.QWidget()
        self.tab3Pie_widget.setObjectName("tab3Pie_widget")
        self.gridLayout_13 = QtWidgets.QGridLayout(self.tab3Pie_widget)
        self.gridLayout_13.setObjectName("gridLayout_13")
        self.noInfoTab3_Label = QtWidgets.QLabel(self.tab3Pie_widget)
        self.noInfoTab3_Label.setObjectName("noInfoTab3_Label")
        self.gridLayout_13.addWidget(self.noInfoTab3_Label, 2, 0, 1, 1)
        self.pieTabWidget = QtWidgets.QTabWidget(self.tab3Pie_widget)
        self.pieTabWidget.setObjectName("pieTabWidget")
        self.tabPie1Region_widget = QtWidgets.QWidget()
        self.tabPie1Region_widget.setObjectName("tabPie1Region_widget")
        self.gridLayout_14 = QtWidgets.QGridLayout(self.tabPie1Region_widget)
        self.gridLayout_14.setObjectName("gridLayout_14")
        self.addGraphic_button = QtWidgets.QPushButton(self.tabPie1Region_widget)
        self.addGraphic_button.setMinimumSize(QtCore.QSize(30, 30))
        self.addGraphic_button.setMaximumSize(QtCore.QSize(30, 30))
        self.addGraphic_button.setObjectName("addGraphic_button")
        self.gridLayout_14.addWidget(self.addGraphic_button, 0, 1, 1, 1)
        self.pieScrollArea = QtWidgets.QScrollArea(self.tabPie1Region_widget)
        self.pieScrollArea.setWidgetResizable(True)
        self.pieScrollArea.setObjectName("pieScrollArea")
        self.regionScrollContent = QtWidgets.QWidget()
        self.regionScrollContent.setGeometry(QtCore.QRect(0, 0, 1303, 828))
        self.regionScrollContent.setObjectName("regionScrollContent")
        self.pieScrollArea.setWidget(self.regionScrollContent)
        self.gridLayout_14.addWidget(self.pieScrollArea, 0, 0, 2, 1)
        spacerItem = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_14.addItem(spacerItem, 1, 1, 1, 1)
        self.pieTabWidget.addTab(self.tabPie1Region_widget, "")
        self.tabPie2Region_widget = QtWidgets.QWidget()
        self.tabPie2Region_widget.setObjectName("tabPie2Region_widget")
        self.gridLayout_6 = QtWidgets.QGridLayout(self.tabPie2Region_widget)
        self.gridLayout_6.setObjectName("gridLayout_6")
        self.addGraphic2_button = QtWidgets.QPushButton(self.tabPie2Region_widget)
        self.addGraphic2_button.setMinimumSize(QtCore.QSize(30, 30))
        self.addGraphic2_button.setMaximumSize(QtCore.QSize(30, 30))
        self.addGraphic2_button.setObjectName("addGraphic2_button")
        self.gridLayout_6.addWidget(self.addGraphic2_button, 0, 1, 1, 1)
        spacerItem1 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_6.addItem(spacerItem1, 1, 1, 1, 1)
        self.pieScrollArea2 = QtWidgets.QScrollArea(self.tabPie2Region_widget)
        self.pieScrollArea2.setWidgetResizable(True)
        self.pieScrollArea2.setObjectName("pieScrollArea2")
        self.regionScrollContent2 = QtWidgets.QWidget()
        self.regionScrollContent2.setGeometry(QtCore.QRect(0, 0, 98, 28))
        self.regionScrollContent2.setObjectName("regionScrollContent2")
        self.pieScrollArea2.setWidget(self.regionScrollContent2)
        self.gridLayout_6.addWidget(self.pieScrollArea2, 0, 0, 2, 1)
        self.pieTabWidget.addTab(self.tabPie2Region_widget, "")
        self.tabPie3Region_widget = QtWidgets.QWidget()
        self.tabPie3Region_widget.setObjectName("tabPie3Region_widget")
        self.gridLayout_20 = QtWidgets.QGridLayout(self.tabPie3Region_widget)
        self.gridLayout_20.setObjectName("gridLayout_20")
        self.addGraphic3_button = QtWidgets.QPushButton(self.tabPie3Region_widget)
        self.addGraphic3_button.setMinimumSize(QtCore.QSize(30, 30))
        self.addGraphic3_button.setMaximumSize(QtCore.QSize(30, 30))
        self.addGraphic3_button.setObjectName("addGraphic3_button")
        self.gridLayout_20.addWidget(self.addGraphic3_button, 0, 1, 1, 1)
        spacerItem2 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_20.addItem(spacerItem2, 1, 1, 1, 1)
        self.pieScrollArea3 = QtWidgets.QScrollArea(self.tabPie3Region_widget)
        self.pieScrollArea3.setWidgetResizable(True)
        self.pieScrollArea3.setObjectName("pieScrollArea3")
        self.regionScrollContent3 = QtWidgets.QWidget()
        self.regionScrollContent3.setGeometry(QtCore.QRect(0, 0, 98, 28))
        self.regionScrollContent3.setObjectName("regionScrollContent3")
        self.pieScrollArea3.setWidget(self.regionScrollContent3)
        self.gridLayout_20.addWidget(self.pieScrollArea3, 0, 0, 2, 1)
        self.pieTabWidget.addTab(self.tabPie3Region_widget, "")
        self.tabPie4Region_widget = QtWidgets.QWidget()
        self.tabPie4Region_widget.setObjectName("tabPie4Region_widget")
        self.gridLayout_21 = QtWidgets.QGridLayout(self.tabPie4Region_widget)
        self.gridLayout_21.setObjectName("gridLayout_21")
        self.addGraphic4_button = QtWidgets.QPushButton(self.tabPie4Region_widget)
        self.addGraphic4_button.setMinimumSize(QtCore.QSize(30, 30))
        self.addGraphic4_button.setMaximumSize(QtCore.QSize(30, 30))
        self.addGraphic4_button.setObjectName("addGraphic4_button")
        self.gridLayout_21.addWidget(self.addGraphic4_button, 0, 1, 1, 1)
        spacerItem3 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_21.addItem(spacerItem3, 1, 1, 1, 1)
        self.pieScrollArea4 = QtWidgets.QScrollArea(self.tabPie4Region_widget)
        self.pieScrollArea4.setWidgetResizable(True)
        self.pieScrollArea4.setObjectName("pieScrollArea4")
        self.regionScrollContent4 = QtWidgets.QWidget()
        self.regionScrollContent4.setGeometry(QtCore.QRect(0, 0, 98, 28))
        self.regionScrollContent4.setObjectName("regionScrollContent4")
        self.pieScrollArea4.setWidget(self.regionScrollContent4)
        self.gridLayout_21.addWidget(self.pieScrollArea4, 0, 0, 2, 1)
        self.pieTabWidget.addTab(self.tabPie4Region_widget, "")
        self.tabPie5Region_widget = QtWidgets.QWidget()
        self.tabPie5Region_widget.setObjectName("tabPie5Region_widget")
        self.gridLayout_22 = QtWidgets.QGridLayout(self.tabPie5Region_widget)
        self.gridLayout_22.setObjectName("gridLayout_22")
        spacerItem4 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_22.addItem(spacerItem4, 1, 2, 1, 1)
        self.addGraphic5_button = QtWidgets.QPushButton(self.tabPie5Region_widget)
        self.addGraphic5_button.setMinimumSize(QtCore.QSize(30, 30))
        self.addGraphic5_button.setMaximumSize(QtCore.QSize(30, 30))
        self.addGraphic5_button.setObjectName("addGraphic5_button")
        self.gridLayout_22.addWidget(self.addGraphic5_button, 0, 2, 1, 1)
        self.pieScrollArea5 = QtWidgets.QScrollArea(self.tabPie5Region_widget)
        self.pieScrollArea5.setWidgetResizable(True)
        self.pieScrollArea5.setObjectName("pieScrollArea5")
        self.regionScrollContent5 = QtWidgets.QWidget()
        self.regionScrollContent5.setGeometry(QtCore.QRect(0, 0, 98, 28))
        self.regionScrollContent5.setObjectName("regionScrollContent5")
        self.pieScrollArea5.setWidget(self.regionScrollContent5)
        self.gridLayout_22.addWidget(self.pieScrollArea5, 0, 1, 2, 1)
        self.pieTabWidget.addTab(self.tabPie5Region_widget, "")
        self.gridLayout_13.addWidget(self.pieTabWidget, 1, 0, 1, 1)
        self.mainTabWidget.addTab(self.tab3Pie_widget, "")
        self.tab4List_widget = QtWidgets.QWidget()
        self.tab4List_widget.setObjectName("tab4List_widget")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.tab4List_widget)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.listSupport_Frame = QtWidgets.QFrame(self.tab4List_widget)
        self.listSupport_Frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.listSupport_Frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.listSupport_Frame.setObjectName("listSupport_Frame")
        self.gridLayout_23 = QtWidgets.QGridLayout(self.listSupport_Frame)
        self.gridLayout_23.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_23.setObjectName("gridLayout_23")
        self.infoList_tableWidget = QtWidgets.QTableWidget(self.listSupport_Frame)
        self.infoList_tableWidget.setRowCount(0)
        self.infoList_tableWidget.setColumnCount(9)
        self.infoList_tableWidget.setObjectName("infoList_tableWidget")
        item = QtWidgets.QTableWidgetItem()
        self.infoList_tableWidget.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.infoList_tableWidget.setHorizontalHeaderItem(1, item)
        item = QtWidgets.QTableWidgetItem()
        self.infoList_tableWidget.setHorizontalHeaderItem(2, item)
        item = QtWidgets.QTableWidgetItem()
        self.infoList_tableWidget.setHorizontalHeaderItem(3, item)
        item = QtWidgets.QTableWidgetItem()
        self.infoList_tableWidget.setHorizontalHeaderItem(4, item)
        item = QtWidgets.QTableWidgetItem()
        self.infoList_tableWidget.setHorizontalHeaderItem(5, item)
        item = QtWidgets.QTableWidgetItem()
        self.infoList_tableWidget.setHorizontalHeaderItem(6, item)
        item = QtWidgets.QTableWidgetItem()
        self.infoList_tableWidget.setHorizontalHeaderItem(7, item)
        item = QtWidgets.QTableWidgetItem()
        self.infoList_tableWidget.setHorizontalHeaderItem(8, item)
        self.infoList_tableWidget.horizontalHeader().setDefaultSectionSize(100)
        self.gridLayout_23.addWidget(self.infoList_tableWidget, 0, 0, 1, 1)
        self.gridLayout_4.addWidget(self.listSupport_Frame, 0, 0, 1, 1)
        self.noInfoTab4_Label = QtWidgets.QLabel(self.tab4List_widget)
        self.noInfoTab4_Label.setObjectName("noInfoTab4_Label")
        self.gridLayout_4.addWidget(self.noInfoTab4_Label, 1, 0, 1, 1)
        self.mainTabWidget.addTab(self.tab4List_widget, "")
        self.tab5GT_widget = QtWidgets.QWidget()
        self.tab5GT_widget.setObjectName("tab5GT_widget")
        self.gridLayout_15 = QtWidgets.QGridLayout(self.tab5GT_widget)
        self.gridLayout_15.setObjectName("gridLayout_15")
        self.noInfoTab5_Label = QtWidgets.QLabel(self.tab5GT_widget)
        self.noInfoTab5_Label.setObjectName("noInfoTab5_Label")
        self.gridLayout_15.addWidget(self.noInfoTab5_Label, 1, 0, 1, 1)
        self.tabGT_TableWidget = QtWidgets.QTabWidget(self.tab5GT_widget)
        self.tabGT_TableWidget.setObjectName("tabGT_TableWidget")
        self.tabGT_widget = QtWidgets.QWidget()
        self.tabGT_widget.setObjectName("tabGT_widget")
        self.gridLayout_25 = QtWidgets.QGridLayout(self.tabGT_widget)
        self.gridLayout_25.setObjectName("gridLayout_25")
        self.GTscrollArea_widget = QtWidgets.QScrollArea(self.tabGT_widget)
        self.GTscrollArea_widget.setWidgetResizable(True)
        self.GTscrollArea_widget.setObjectName("GTscrollArea_widget")
        self.regionScrollContentGT = QtWidgets.QWidget()
        self.regionScrollContentGT.setGeometry(QtCore.QRect(0, 0, 98, 28))
        self.regionScrollContentGT.setObjectName("regionScrollContentGT")
        self.GTscrollArea_widget.setWidget(self.regionScrollContentGT)
        self.gridLayout_25.addWidget(self.GTscrollArea_widget, 0, 0, 1, 1)
        self.tabGT_TableWidget.addTab(self.tabGT_widget, "")
        self.tab2GT_widget = QtWidgets.QWidget()
        self.tab2GT_widget.setObjectName("tab2GT_widget")
        self.gridLayout_24 = QtWidgets.QGridLayout(self.tab2GT_widget)
        self.gridLayout_24.setObjectName("gridLayout_24")
        self.gtList_tableWidget = QtWidgets.QTableWidget(self.tab2GT_widget)
        self.gtList_tableWidget.setObjectName("gtList_tableWidget")
        self.gtList_tableWidget.setColumnCount(2)
        self.gtList_tableWidget.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.gtList_tableWidget.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.gtList_tableWidget.setHorizontalHeaderItem(1, item)
        self.gridLayout_24.addWidget(self.gtList_tableWidget, 0, 0, 1, 1)
        self.tabGT_TableWidget.addTab(self.tab2GT_widget, "")
        self.gridLayout_15.addWidget(self.tabGT_TableWidget, 0, 0, 1, 1)
        self.mainTabWidget.addTab(self.tab5GT_widget, "")
        self.gridLayout_9.addWidget(self.mainTabWidget, 0, 0, 1, 1)
        IACOB.setCentralWidget(self.centralWidget)
        self.menuBar = QtWidgets.QMenuBar(IACOB)
        self.menuBar.setGeometry(QtCore.QRect(0, 0, 1736, 21))
        font = QtGui.QFont()
        font.setPointSize(10)
        self.menuBar.setFont(font)
        self.menuBar.setObjectName("menuBar")
        IACOB.setMenuBar(self.menuBar)
        self.statuBar = QtWidgets.QStatusBar(IACOB)
        self.statuBar.setObjectName("statuBar")
        IACOB.setStatusBar(self.statuBar)
        self.dockWidget = QtWidgets.QDockWidget(IACOB)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.dockWidget.sizePolicy().hasHeightForWidth())
        self.dockWidget.setSizePolicy(sizePolicy)
        self.dockWidget.setAllowedAreas(QtCore.Qt.LeftDockWidgetArea|QtCore.Qt.RightDockWidgetArea)
        self.dockWidget.setWindowTitle("")
        self.dockWidget.setObjectName("dockWidget")
        self.dockWidgetContents = QtWidgets.QWidget()
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.dockWidgetContents.sizePolicy().hasHeightForWidth())
        self.dockWidgetContents.setSizePolicy(sizePolicy)
        self.dockWidgetContents.setObjectName("dockWidgetContents")
        self.gridLayout_12 = QtWidgets.QGridLayout(self.dockWidgetContents)
        self.gridLayout_12.setObjectName("gridLayout_12")
        self.info_groupBox = QtWidgets.QGroupBox(self.dockWidgetContents)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.info_groupBox.sizePolicy().hasHeightForWidth())
        self.info_groupBox.setSizePolicy(sizePolicy)
        self.info_groupBox.setObjectName("info_groupBox")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.info_groupBox)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.resetFilter_button = QtWidgets.QToolButton(self.info_groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.resetFilter_button.sizePolicy().hasHeightForWidth())
        self.resetFilter_button.setSizePolicy(sizePolicy)
        self.resetFilter_button.setCheckable(False)
        self.resetFilter_button.setObjectName("resetFilter_button")
        self.verticalLayout_2.addWidget(self.resetFilter_button)
        self.resetGraphicFilter_button = QtWidgets.QToolButton(self.info_groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.resetGraphicFilter_button.sizePolicy().hasHeightForWidth())
        self.resetGraphicFilter_button.setSizePolicy(sizePolicy)
        self.resetGraphicFilter_button.setObjectName("resetGraphicFilter_button")
        self.verticalLayout_2.addWidget(self.resetGraphicFilter_button)
        self.verticalLayout_2.setStretch(0, 50)
        self.verticalLayout_2.setStretch(1, 50)
        self.horizontalLayout.addLayout(self.verticalLayout_2)
        self.gridLayout_2 = QtWidgets.QGridLayout()
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.connNum_label = QtWidgets.QLabel(self.info_groupBox)
        self.connNum_label.setObjectName("connNum_label")
        self.gridLayout_2.addWidget(self.connNum_label, 2, 0, 1, 1)
        self.weightSum_label = QtWidgets.QLabel(self.info_groupBox)
        self.weightSum_label.setObjectName("weightSum_label")
        self.gridLayout_2.addWidget(self.weightSum_label, 0, 0, 1, 1)
        self.weightMean_label = QtWidgets.QLabel(self.info_groupBox)
        self.weightMean_label.setObjectName("weightMean_label")
        self.gridLayout_2.addWidget(self.weightMean_label, 1, 0, 1, 1)
        self.weightSumValue_label = QtWidgets.QLabel(self.info_groupBox)
        self.weightSumValue_label.setObjectName("weightSumValue_label")
        self.gridLayout_2.addWidget(self.weightSumValue_label, 0, 1, 1, 1)
        self.weightMeanValue_label = QtWidgets.QLabel(self.info_groupBox)
        self.weightMeanValue_label.setObjectName("weightMeanValue_label")
        self.gridLayout_2.addWidget(self.weightMeanValue_label, 1, 1, 1, 1)
        self.connNumValue_label = QtWidgets.QLabel(self.info_groupBox)
        self.connNumValue_label.setObjectName("connNumValue_label")
        self.gridLayout_2.addWidget(self.connNumValue_label, 2, 1, 1, 1)
        self.gridLayout_2.setColumnStretch(0, 80)
        self.gridLayout_2.setColumnStretch(1, 20)
        self.horizontalLayout.addLayout(self.gridLayout_2)
        self.horizontalLayout.setStretch(0, 50)
        self.horizontalLayout.setStretch(1, 50)
        self.gridLayout_12.addWidget(self.info_groupBox, 0, 0, 1, 2)
        self.rank_groupBox = QtWidgets.QGroupBox(self.dockWidgetContents)
        self.rank_groupBox.setObjectName("rank_groupBox")
        self.gridLayout_11 = QtWidgets.QGridLayout(self.rank_groupBox)
        self.gridLayout_11.setObjectName("gridLayout_11")
        self.discardRank_spinBox = QtWidgets.QSpinBox(self.rank_groupBox)
        self.discardRank_spinBox.setObjectName("discardRank_spinBox")
        self.gridLayout_11.addWidget(self.discardRank_spinBox, 0, 1, 1, 1)
        self.discardRank_checkBox = QtWidgets.QCheckBox(self.rank_groupBox)
        self.discardRank_checkBox.setObjectName("discardRank_checkBox")
        self.gridLayout_11.addWidget(self.discardRank_checkBox, 0, 0, 1, 1)
        self.gridLayout_11.setColumnStretch(0, 85)
        self.gridLayout_12.addWidget(self.rank_groupBox, 1, 1, 1, 1)
        self.connType_groupBox = QtWidgets.QGroupBox(self.dockWidgetContents)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.connType_groupBox.sizePolicy().hasHeightForWidth())
        self.connType_groupBox.setSizePolicy(sizePolicy)
        self.connType_groupBox.setObjectName("connType_groupBox")
        self.gridLayout_7 = QtWidgets.QGridLayout(self.connType_groupBox)
        self.gridLayout_7.setObjectName("gridLayout_7")
        self.contralateral_checkBox = QtWidgets.QCheckBox(self.connType_groupBox)
        self.contralateral_checkBox.setObjectName("contralateral_checkBox")
        self.gridLayout_7.addWidget(self.contralateral_checkBox, 0, 0, 1, 1)
        self.ipsilateral_checkBox = QtWidgets.QCheckBox(self.connType_groupBox)
        self.ipsilateral_checkBox.setObjectName("ipsilateral_checkBox")
        self.gridLayout_7.addWidget(self.ipsilateral_checkBox, 0, 1, 1, 1)
        self.homotopic_checkBox = QtWidgets.QCheckBox(self.connType_groupBox)
        self.homotopic_checkBox.setObjectName("homotopic_checkBox")
        self.gridLayout_7.addWidget(self.homotopic_checkBox, 1, 0, 1, 1)
        self.other_checkBox = QtWidgets.QCheckBox(self.connType_groupBox)
        self.other_checkBox.setObjectName("other_checkBox")
        self.gridLayout_7.addWidget(self.other_checkBox, 1, 1, 1, 1)
        self.gridLayout_12.addWidget(self.connType_groupBox, 3, 0, 1, 2)
        self.connSelection_groupBox = QtWidgets.QGroupBox(self.dockWidgetContents)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.connSelection_groupBox.sizePolicy().hasHeightForWidth())
        self.connSelection_groupBox.setSizePolicy(sizePolicy)
        self.connSelection_groupBox.setObjectName("connSelection_groupBox")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.connSelection_groupBox)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.gridLayout_12.addWidget(self.connSelection_groupBox, 2, 0, 1, 2)
        self.gtView_groupBox = QtWidgets.QGroupBox(self.dockWidgetContents)
        self.gtView_groupBox.setEnabled(True)
        self.gtView_groupBox.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.gtView_groupBox.setObjectName("gtView_groupBox")
        self.gridLayout_8 = QtWidgets.QGridLayout(self.gtView_groupBox)
        self.gridLayout_8.setObjectName("gridLayout_8")
        self.binary_checkBox = QtWidgets.QCheckBox(self.gtView_groupBox)
        self.binary_checkBox.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.binary_checkBox.setObjectName("binary_checkBox")
        self.gridLayout_8.addWidget(self.binary_checkBox, 1, 2, 1, 1)
        self.binaryThreshold_SpinBox = QtWidgets.QDoubleSpinBox(self.gtView_groupBox)
        self.binaryThreshold_SpinBox.setObjectName("binaryThreshold_SpinBox")
        self.gridLayout_8.addWidget(self.binaryThreshold_SpinBox, 1, 3, 1, 1)
        spacerItem5 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout_8.addItem(spacerItem5, 1, 1, 1, 1)
        self.addGraphGT_button = QtWidgets.QPushButton(self.gtView_groupBox)
        self.addGraphGT_button.setMinimumSize(QtCore.QSize(30, 30))
        self.addGraphGT_button.setMaximumSize(QtCore.QSize(30, 30))
        self.addGraphGT_button.setText("")
        self.addGraphGT_button.setObjectName("addGraphGT_button")
        self.gridLayout_8.addWidget(self.addGraphGT_button, 1, 0, 1, 1)
        self.gridLayout_8.setColumnStretch(0, 10)
        self.gridLayout_8.setColumnStretch(1, 5)
        self.gridLayout_8.setColumnStretch(2, 5)
        self.gridLayout_8.setColumnStretch(3, 5)
        self.gridLayout_12.addWidget(self.gtView_groupBox, 6, 0, 1, 2)
        self.edgeView_groupBox = QtWidgets.QGroupBox(self.dockWidgetContents)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.edgeView_groupBox.sizePolicy().hasHeightForWidth())
        self.edgeView_groupBox.setSizePolicy(sizePolicy)
        self.edgeView_groupBox.setObjectName("edgeView_groupBox")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(self.edgeView_groupBox)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.widthCoef_label = QtWidgets.QLabel(self.edgeView_groupBox)
        self.widthCoef_label.setObjectName("widthCoef_label")
        self.horizontalLayout_3.addWidget(self.widthCoef_label)
        self.widthCoefValue_spinBox = QtWidgets.QDoubleSpinBox(self.edgeView_groupBox)
        self.widthCoefValue_spinBox.setObjectName("widthCoefValue_spinBox")
        self.horizontalLayout_3.addWidget(self.widthCoefValue_spinBox)
        self.gridLayout_12.addWidget(self.edgeView_groupBox, 4, 0, 1, 1)
        self.weightGroup_groupBox = QtWidgets.QGroupBox(self.dockWidgetContents)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.weightGroup_groupBox.sizePolicy().hasHeightForWidth())
        self.weightGroup_groupBox.setSizePolicy(sizePolicy)
        self.weightGroup_groupBox.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.weightGroup_groupBox.setObjectName("weightGroup_groupBox")
        self.gridLayout_10 = QtWidgets.QGridLayout(self.weightGroup_groupBox)
        self.gridLayout_10.setObjectName("gridLayout_10")
        self.discardAbsWeight_spinBox = QtWidgets.QDoubleSpinBox(self.weightGroup_groupBox)
        self.discardAbsWeight_spinBox.setObjectName("discardAbsWeight_spinBox")
        self.gridLayout_10.addWidget(self.discardAbsWeight_spinBox, 2, 1, 1, 1)
        self.discardWeight_checkBox = QtWidgets.QCheckBox(self.weightGroup_groupBox)
        self.discardWeight_checkBox.setObjectName("discardWeight_checkBox")
        self.gridLayout_10.addWidget(self.discardWeight_checkBox, 0, 0, 1, 1)
        self.discardAbsWeight_checkBox = QtWidgets.QCheckBox(self.weightGroup_groupBox)
        self.discardAbsWeight_checkBox.setObjectName("discardAbsWeight_checkBox")
        self.gridLayout_10.addWidget(self.discardAbsWeight_checkBox, 2, 0, 1, 1)
        self.discardWeightUp_spinBox = QtWidgets.QDoubleSpinBox(self.weightGroup_groupBox)
        self.discardWeightUp_spinBox.setObjectName("discardWeightUp_spinBox")
        self.gridLayout_10.addWidget(self.discardWeightUp_spinBox, 0, 1, 1, 1)
        self.discardWeightDown_spinBox = QtWidgets.QDoubleSpinBox(self.weightGroup_groupBox)
        self.discardWeightDown_spinBox.setObjectName("discardWeightDown_spinBox")
        self.gridLayout_10.addWidget(self.discardWeightDown_spinBox, 1, 1, 1, 1)
        self.gridLayout_10.setColumnStretch(0, 85)
        self.gridLayout_12.addWidget(self.weightGroup_groupBox, 1, 0, 1, 1)
        self.edgeColor_groupBox = QtWidgets.QGroupBox(self.dockWidgetContents)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.edgeColor_groupBox.sizePolicy().hasHeightForWidth())
        self.edgeColor_groupBox.setSizePolicy(sizePolicy)
        self.edgeColor_groupBox.setObjectName("edgeColor_groupBox")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.edgeColor_groupBox)
        self.verticalLayout.setObjectName("verticalLayout")
        self.colorPalette_comboBox = QtWidgets.QComboBox(self.edgeColor_groupBox)
        self.colorPalette_comboBox.setEditable(False)
        self.colorPalette_comboBox.setObjectName("colorPalette_comboBox")
        self.verticalLayout.addWidget(self.colorPalette_comboBox)
        self.displayColorPalette_Label = QtWidgets.QLabel(self.edgeColor_groupBox)
        self.displayColorPalette_Label.setText("")
        self.displayColorPalette_Label.setObjectName("displayColorPalette_Label")
        self.verticalLayout.addWidget(self.displayColorPalette_Label)
        self.gridLayout_12.addWidget(self.edgeColor_groupBox, 4, 1, 1, 1)
        self.export_Layout = QtWidgets.QGridLayout()
        self.export_Layout.setObjectName("export_Layout")
        self.exportList_button = QtWidgets.QToolButton(self.dockWidgetContents)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.exportList_button.sizePolicy().hasHeightForWidth())
        self.exportList_button.setSizePolicy(sizePolicy)
        self.exportList_button.setMinimumSize(QtCore.QSize(0, 30))
        self.exportList_button.setMaximumSize(QtCore.QSize(16777215, 30))
        self.exportList_button.setObjectName("exportList_button")
        self.export_Layout.addWidget(self.exportList_button, 0, 0, 1, 1)
        self.exportCircular_button = QtWidgets.QToolButton(self.dockWidgetContents)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.exportCircular_button.sizePolicy().hasHeightForWidth())
        self.exportCircular_button.setSizePolicy(sizePolicy)
        self.exportCircular_button.setMinimumSize(QtCore.QSize(0, 30))
        self.exportCircular_button.setMaximumSize(QtCore.QSize(16777215, 30))
        self.exportCircular_button.setObjectName("exportCircular_button")
        self.export_Layout.addWidget(self.exportCircular_button, 1, 0, 1, 1)
        self.gridLayout_12.addLayout(self.export_Layout, 5, 0, 1, 2)
        spacerItem6 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_12.addItem(spacerItem6, 7, 0, 1, 2)
        self.gridLayout_12.setRowStretch(0, 10)
        self.gridLayout_12.setRowStretch(1, 10)
        self.gridLayout_12.setRowStretch(2, 100)
        self.gridLayout_12.setRowStretch(3, 10)
        self.gridLayout_12.setRowStretch(4, 10)
        self.gridLayout_12.setRowStretch(5, 10)
        self.gridLayout_12.setRowStretch(6, 10)
        self.gridLayout_12.setRowStretch(7, 100)
        self.dockWidget.setWidget(self.dockWidgetContents)
        IACOB.addDockWidget(QtCore.Qt.DockWidgetArea(2), self.dockWidget)

        self.retranslateUi(IACOB)
        self.mainTabWidget.setCurrentIndex(0)
        self.pieTabWidget.setCurrentIndex(0)
        self.tabGT_TableWidget.setCurrentIndex(1)
        QtCore.QMetaObject.connectSlotsByName(IACOB)

    def retranslateUi(self, IACOB):
        _translate = QtCore.QCoreApplication.translate
        IACOB.setWindowTitle(_translate("IACOB", "MainWindow"))
        self.mainTabWidget.setProperty("class", _translate("IACOB", "whiteGrayTabWidget"))
        self.openedFiles_Label.setText(_translate("IACOB", "File Opened\n"
"(Data / FLUT)"))
        self.openedFiles_Label.setProperty("class", _translate("IACOB", "standardLabel"))
        self.openedDataFile_Label.setText(_translate("IACOB", "Data File :"))
        self.openedDataFile_Label.setProperty("class", _translate("IACOB", "infoLabel"))
        self.currentDataFile_Label.setProperty("class", _translate("IACOB", "valueLabel"))
        self.openedFlutFile_Label.setText(_translate("IACOB", "FLUT File :"))
        self.openedFlutFile_Label.setProperty("class", _translate("IACOB", "infoLabel"))
        self.currentFlutFile_Label.setProperty("class", _translate("IACOB", "valueLabel"))
        self.nbNodesValue_Label.setProperty("class", _translate("IACOB", "valueLabel"))
        self.nbNodes_Label.setText(_translate("IACOB", "Number of Nodes :"))
        self.nbNodes_Label.setProperty("class", _translate("IACOB", "infoLabel"))
        self.nbConnections_Label.setText(_translate("IACOB", "Number of Connections :"))
        self.nbConnections_Label.setProperty("class", _translate("IACOB", "infoLabel"))
        self.sumAbsValue_Label.setProperty("class", _translate("IACOB", "valueLabel"))
        self.standardDeviation_Label.setText(_translate("IACOB", "Standard\n"
"Deviation"))
        self.standardDeviation_Label.setProperty("class", _translate("IACOB", "infoLabel"))
        self.max_Label.setText(_translate("IACOB", "Max ABS :"))
        self.max_Label.setProperty("class", _translate("IACOB", "infoLabel"))
        self.standardDeviationValue_Label.setProperty("class", _translate("IACOB", "valueLabel"))
        self.sumAbs_Label.setText(_translate("IACOB", "Sum (ABS) :"))
        self.sumAbs_Label.setProperty("class", _translate("IACOB", "infoLabel"))
        self.nbConnectionsValue_Label.setProperty("class", _translate("IACOB", "valueLabel"))
        self.meanAbsValue_Label.setProperty("class", _translate("IACOB", "valueLabel"))
        self.maxValue_Label.setProperty("class", _translate("IACOB", "valueLabel"))
        self.meanAbs_Label.setText(_translate("IACOB", "Mean (ABS) :"))
        self.meanAbs_Label.setProperty("class", _translate("IACOB", "infoLabel"))
        self.thresholdValue_Label.setProperty("class", _translate("IACOB", "valueLabel"))
        self.minValue_Label.setProperty("class", _translate("IACOB", "valueLabel"))
        self.min_Label.setText(_translate("IACOB", "Min ABS :"))
        self.min_Label.setProperty("class", _translate("IACOB", "infoLabel"))
        self.threshold_Label.setText(_translate("IACOB", "Threshold :"))
        self.threshold_Label.setProperty("class", _translate("IACOB", "infoLabel"))
        self.maxRelValue_Label.setProperty("class", _translate("IACOB", "valueLabel"))
        self.minRel_Label.setText(_translate("IACOB", "Max REL :"))
        self.minRel_Label.setProperty("class", _translate("IACOB", "infoLabel"))
        self.maxRel_Label.setText(_translate("IACOB", "Min REL :"))
        self.maxRel_Label.setProperty("class", _translate("IACOB", "infoLabel"))
        self.minRelValue_Label.setProperty("class", _translate("IACOB", "valueLabel"))
        self.noInfoTab1_Label.setText(_translate("IACOB", "No File Loaded"))
        self.noInfoTab1_Label.setProperty("class", _translate("IACOB", "noFileLabel"))
        self.mainTabWidget.setTabText(self.mainTabWidget.indexOf(self.tab1FileInfo_widget), _translate("IACOB", "File Info"))
        self.noInfoTab2_Label.setText(_translate("IACOB", "No File Loaded"))
        self.noInfoTab2_Label.setProperty("class", _translate("IACOB", "noFileLabel"))
        self.mainTabWidget.setTabText(self.mainTabWidget.indexOf(self.tab2Circular_widget), _translate("IACOB", "Circular"))
        self.noInfoTab3_Label.setText(_translate("IACOB", "No File Loaded"))
        self.noInfoTab3_Label.setProperty("class", _translate("IACOB", "noFileLabel"))
        self.pieTabWidget.setProperty("class", _translate("IACOB", "whiteGrayTabWidget"))
        self.addGraphic_button.setProperty("class", _translate("IACOB", "whiteBGButton"))
        self.pieTabWidget.setTabText(self.pieTabWidget.indexOf(self.tabPie1Region_widget), _translate("IACOB", "Areas"))
        self.addGraphic2_button.setProperty("class", _translate("IACOB", "whiteBGButton"))
        self.pieTabWidget.setTabText(self.pieTabWidget.indexOf(self.tabPie2Region_widget), _translate("IACOB", "Major Regions"))
        self.addGraphic3_button.setProperty("class", _translate("IACOB", "whiteBGButton"))
        self.pieTabWidget.setTabText(self.pieTabWidget.indexOf(self.tabPie3Region_widget), _translate("IACOB", "Major Regions (bar)"))
        self.addGraphic4_button.setProperty("class", _translate("IACOB", "whiteBGButton"))
        self.pieTabWidget.setTabText(self.pieTabWidget.indexOf(self.tabPie4Region_widget), _translate("IACOB", "Connection Type"))
        self.addGraphic5_button.setProperty("class", _translate("IACOB", "whiteBGButton"))
        self.pieTabWidget.setTabText(self.pieTabWidget.indexOf(self.tabPie5Region_widget), _translate("IACOB", "Connection Type (bar)"))
        self.mainTabWidget.setTabText(self.mainTabWidget.indexOf(self.tab3Pie_widget), _translate("IACOB", "Pie"))
        self.infoList_tableWidget.setProperty("class", _translate("IACOB", "infoTable"))
        item = self.infoList_tableWidget.horizontalHeaderItem(0)
        item.setText(_translate("IACOB", "Node 1"))
        item = self.infoList_tableWidget.horizontalHeaderItem(1)
        item.setText(_translate("IACOB", "Node 2"))
        item = self.infoList_tableWidget.horizontalHeaderItem(2)
        item.setText(_translate("IACOB", "Label 1"))
        item = self.infoList_tableWidget.horizontalHeaderItem(3)
        item.setText(_translate("IACOB", "Label 2"))
        item = self.infoList_tableWidget.horizontalHeaderItem(4)
        item.setText(_translate("IACOB", "Region 1"))
        item = self.infoList_tableWidget.horizontalHeaderItem(5)
        item.setText(_translate("IACOB", "Region 2"))
        item = self.infoList_tableWidget.horizontalHeaderItem(6)
        item.setText(_translate("IACOB", "Connection type"))
        item = self.infoList_tableWidget.horizontalHeaderItem(7)
        item.setText(_translate("IACOB", "Connectivity"))
        item = self.infoList_tableWidget.horizontalHeaderItem(8)
        item.setText(_translate("IACOB", "Rank"))
        self.noInfoTab4_Label.setText(_translate("IACOB", "No File Loaded"))
        self.noInfoTab4_Label.setProperty("class", _translate("IACOB", "noFileLabel"))
        self.mainTabWidget.setTabText(self.mainTabWidget.indexOf(self.tab4List_widget), _translate("IACOB", "List"))
        self.noInfoTab5_Label.setText(_translate("IACOB", "No File Loaded"))
        self.noInfoTab5_Label.setProperty("class", _translate("IACOB", "noFileLabel"))
        self.tabGT_TableWidget.setProperty("class", _translate("IACOB", "whiteGrayTabWidget"))
        self.tabGT_TableWidget.setTabText(self.tabGT_TableWidget.indexOf(self.tabGT_widget), _translate("IACOB", "Local"))
        self.gtList_tableWidget.setProperty("class", _translate("IACOB", "infoTable"))
        item = self.gtList_tableWidget.horizontalHeaderItem(0)
        item.setText(_translate("IACOB", "Global Measures"))
        item = self.gtList_tableWidget.horizontalHeaderItem(1)
        item.setText(_translate("IACOB", "Values (ABS Graph)"))
        self.tabGT_TableWidget.setTabText(self.tabGT_TableWidget.indexOf(self.tab2GT_widget), _translate("IACOB", "Global"))
        self.mainTabWidget.setTabText(self.mainTabWidget.indexOf(self.tab5GT_widget), _translate("IACOB", "GT"))
        self.info_groupBox.setTitle(_translate("IACOB", "Info"))
        self.info_groupBox.setProperty("class", _translate("IACOB", "filterGroupBox"))
        self.resetFilter_button.setText(_translate("IACOB", "Reset filter"))
        self.resetFilter_button.setProperty("class", _translate("IACOB", "grayRoundedButton"))
        self.resetGraphicFilter_button.setText(_translate("IACOB", "Reset graphic filter"))
        self.resetGraphicFilter_button.setProperty("class", _translate("IACOB", "grayRoundedButton"))
        self.connNum_label.setText(_translate("IACOB", "Connectivity number :"))
        self.connNum_label.setProperty("class", _translate("IACOB", "filterParamLabel"))
        self.weightSum_label.setText(_translate("IACOB", "Weights sum :"))
        self.weightSum_label.setProperty("class", _translate("IACOB", "filterParamLabel"))
        self.weightMean_label.setText(_translate("IACOB", "Weights mean :"))
        self.weightMean_label.setProperty("class", _translate("IACOB", "filterParamLabel"))
        self.weightSumValue_label.setText(_translate("IACOB", "..."))
        self.weightSumValue_label.setProperty("class", _translate("IACOB", "valueLabel"))
        self.weightMeanValue_label.setText(_translate("IACOB", "..."))
        self.weightMeanValue_label.setProperty("class", _translate("IACOB", "valueLabel"))
        self.connNumValue_label.setText(_translate("IACOB", "..."))
        self.connNumValue_label.setProperty("class", _translate("IACOB", "valueLabel"))
        self.rank_groupBox.setTitle(_translate("IACOB", "Rank Filter"))
        self.rank_groupBox.setProperty("class", _translate("IACOB", "filterGroupBox"))
        self.discardRank_spinBox.setProperty("class", _translate("IACOB", "blackSpinBox"))
        self.discardRank_checkBox.setText(_translate("IACOB", "Discard rank >"))
        self.discardRank_checkBox.setProperty("class", _translate("IACOB", "blackCheckBox"))
        self.connType_groupBox.setTitle(_translate("IACOB", "Type of connection"))
        self.connType_groupBox.setProperty("class", _translate("IACOB", "filterGroupBox"))
        self.contralateral_checkBox.setText(_translate("IACOB", "Contralateral"))
        self.contralateral_checkBox.setProperty("class", _translate("IACOB", "blackCheckBox"))
        self.ipsilateral_checkBox.setText(_translate("IACOB", "Ipsilateral"))
        self.ipsilateral_checkBox.setProperty("class", _translate("IACOB", "blackCheckBox"))
        self.homotopic_checkBox.setText(_translate("IACOB", "Homotopic"))
        self.homotopic_checkBox.setProperty("class", _translate("IACOB", "blackCheckBox"))
        self.other_checkBox.setText(_translate("IACOB", "Other"))
        self.other_checkBox.setProperty("class", _translate("IACOB", "blackCheckBox"))
        self.connSelection_groupBox.setTitle(_translate("IACOB", "Inter-regional connections"))
        self.connSelection_groupBox.setProperty("class", _translate("IACOB", "filterGroupBox"))
        self.gtView_groupBox.setTitle(_translate("IACOB", "GT view"))
        self.gtView_groupBox.setProperty("class", _translate("IACOB", "filterGroupBox"))
        self.binary_checkBox.setText(_translate("IACOB", "Binary"))
        self.binary_checkBox.setProperty("class", _translate("IACOB", "blackCheckBox"))
        self.binaryThreshold_SpinBox.setProperty("class", _translate("IACOB", "blackSpinBox"))
        self.addGraphGT_button.setProperty("class", _translate("IACOB", "grayBGButton"))
        self.edgeView_groupBox.setTitle(_translate("IACOB", "Edge view"))
        self.edgeView_groupBox.setProperty("class", _translate("IACOB", "filterGroupBox"))
        self.widthCoef_label.setText(_translate("IACOB", "Width coefficient :"))
        self.widthCoef_label.setProperty("class", _translate("IACOB", "filterParamLabel"))
        self.widthCoefValue_spinBox.setProperty("class", _translate("IACOB", "blackSpinBox"))
        self.weightGroup_groupBox.setTitle(_translate("IACOB", "Weight Filter"))
        self.weightGroup_groupBox.setProperty("class", _translate("IACOB", "filterGroupBox"))
        self.discardAbsWeight_spinBox.setProperty("class", _translate("IACOB", "blackSpinBox"))
        self.discardWeight_checkBox.setText(_translate("IACOB", "Discard weight >= / <="))
        self.discardWeight_checkBox.setProperty("class", _translate("IACOB", "blackCheckBox"))
        self.discardAbsWeight_checkBox.setText(_translate("IACOB", "Discard abs weight >="))
        self.discardAbsWeight_checkBox.setProperty("class", _translate("IACOB", "blackCheckBox"))
        self.discardWeightUp_spinBox.setProperty("class", _translate("IACOB", "blackSpinBox"))
        self.discardWeightDown_spinBox.setProperty("class", _translate("IACOB", "blackSpinBox"))
        self.edgeColor_groupBox.setTitle(_translate("IACOB", "Edge color"))
        self.edgeColor_groupBox.setProperty("class", _translate("IACOB", "filterGroupBox"))
        self.colorPalette_comboBox.setProperty("class", _translate("IACOB", "blackComboBox"))
        self.displayColorPalette_Label.setProperty("class", _translate("IACOB", "displayEdgesColor"))
        self.exportList_button.setText(_translate("IACOB", "Export List"))
        self.exportList_button.setProperty("class", _translate("IACOB", "grayRoundedButton"))
        self.exportCircular_button.setText(_translate("IACOB", "Export Circular Graph"))
        self.exportCircular_button.setProperty("class", _translate("IACOB", "grayRoundedButton"))
