class DataSingleton(type):
    """
    Singleton Structure (Metaclass Type)
    """

    _instances = {}

    def __call__(cls, *args, **kwargs):

        if cls not in cls._instances:
            cls._instances[cls] = super(DataSingleton, cls).__call__(*args, **kwargs)
            
        return cls._instances[cls]