# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '.\ressources\QT_ui\ImportWindow.ui'
#
# Created by: PyQt5 UI code generator 5.15.10
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_ImportWindow(object):
    def setupUi(self, ImportWindow):
        ImportWindow.setObjectName("ImportWindow")
        ImportWindow.resize(1800, 900)
        ImportWindow.setMinimumSize(QtCore.QSize(0, 0))
        ImportWindow.setMaximumSize(QtCore.QSize(16777215, 16777215))
        ImportWindow.setAutoFillBackground(True)
        self.centralwidget = QtWidgets.QWidget(ImportWindow)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.centralwidget.sizePolicy().hasHeightForWidth())
        self.centralwidget.setSizePolicy(sizePolicy)
        self.centralwidget.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout = QtWidgets.QGridLayout(self.centralwidget)
        self.gridLayout.setObjectName("gridLayout")
        self.graphSection_Widget = QtWidgets.QWidget(self.centralwidget)
        self.graphSection_Widget.setMinimumSize(QtCore.QSize(0, 0))
        self.graphSection_Widget.setObjectName("graphSection_Widget")
        self.gridLayout_9 = QtWidgets.QGridLayout(self.graphSection_Widget)
        self.gridLayout_9.setContentsMargins(-1, 7, -1, -1)
        self.gridLayout_9.setObjectName("gridLayout_9")
        self.graphControl_Widget = QtWidgets.QWidget(self.graphSection_Widget)
        self.graphControl_Widget.setObjectName("graphControl_Widget")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.graphControl_Widget)
        self.gridLayout_2.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.limitedGraph_TabWidget = QtWidgets.QTabWidget(self.graphControl_Widget)
        self.limitedGraph_TabWidget.setMinimumSize(QtCore.QSize(0, 0))
        self.limitedGraph_TabWidget.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.limitedGraph_TabWidget.setTabBarAutoHide(False)
        self.limitedGraph_TabWidget.setObjectName("limitedGraph_TabWidget")
        self.threshodTab_Widget = QtWidgets.QWidget()
        self.threshodTab_Widget.setObjectName("threshodTab_Widget")
        self.gridLayout_12 = QtWidgets.QGridLayout(self.threshodTab_Widget)
        self.gridLayout_12.setObjectName("gridLayout_12")
        self.slider_Widget = QtWidgets.QWidget(self.threshodTab_Widget)
        self.slider_Widget.setObjectName("slider_Widget")
        self.gridLayout_11 = QtWidgets.QGridLayout(self.slider_Widget)
        self.gridLayout_11.setObjectName("gridLayout_11")
        spacerItem = QtWidgets.QSpacerItem(20, 834, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_11.addItem(spacerItem, 1, 1, 1, 1)
        self.minSlider_Label = QtWidgets.QLabel(self.slider_Widget)
        self.minSlider_Label.setMinimumSize(QtCore.QSize(0, 0))
        self.minSlider_Label.setObjectName("minSlider_Label")
        self.gridLayout_11.addWidget(self.minSlider_Label, 2, 1, 1, 1)
        self.maxSlider_Label = QtWidgets.QLabel(self.slider_Widget)
        self.maxSlider_Label.setMinimumSize(QtCore.QSize(0, 0))
        self.maxSlider_Label.setObjectName("maxSlider_Label")
        self.gridLayout_11.addWidget(self.maxSlider_Label, 0, 1, 1, 1)
        self.threshold_Slider = QtWidgets.QSlider(self.slider_Widget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.threshold_Slider.sizePolicy().hasHeightForWidth())
        self.threshold_Slider.setSizePolicy(sizePolicy)
        self.threshold_Slider.setOrientation(QtCore.Qt.Vertical)
        self.threshold_Slider.setTickPosition(QtWidgets.QSlider.NoTicks)
        self.threshold_Slider.setObjectName("threshold_Slider")
        self.gridLayout_11.addWidget(self.threshold_Slider, 0, 0, 3, 1)
        self.gridLayout_11.setColumnStretch(0, 30)
        self.gridLayout_11.setColumnStretch(1, 70)
        self.gridLayout_12.addWidget(self.slider_Widget, 0, 0, 1, 1)
        self.thresholdDisplay_Widget = QtWidgets.QWidget(self.threshodTab_Widget)
        self.thresholdDisplay_Widget.setMinimumSize(QtCore.QSize(0, 0))
        self.thresholdDisplay_Widget.setObjectName("thresholdDisplay_Widget")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(self.thresholdDisplay_Widget)
        self.horizontalLayout_4.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.threshold_Label = QtWidgets.QLabel(self.thresholdDisplay_Widget)
        self.threshold_Label.setMinimumSize(QtCore.QSize(0, 0))
        self.threshold_Label.setObjectName("threshold_Label")
        self.horizontalLayout_4.addWidget(self.threshold_Label)
        self.thresholdValue_DoubleSpinBox = QtWidgets.QDoubleSpinBox(self.thresholdDisplay_Widget)
        self.thresholdValue_DoubleSpinBox.setObjectName("thresholdValue_DoubleSpinBox")
        self.horizontalLayout_4.addWidget(self.thresholdValue_DoubleSpinBox)
        self.horizontalLayout_4.setStretch(0, 2)
        self.horizontalLayout_4.setStretch(1, 4)
        self.gridLayout_12.addWidget(self.thresholdDisplay_Widget, 1, 0, 1, 1)
        self.rankDisplay_Widget = QtWidgets.QFrame(self.threshodTab_Widget)
        self.rankDisplay_Widget.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.rankDisplay_Widget.setFrameShadow(QtWidgets.QFrame.Raised)
        self.rankDisplay_Widget.setObjectName("rankDisplay_Widget")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.rankDisplay_Widget)
        self.horizontalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.rank_Label = QtWidgets.QLabel(self.rankDisplay_Widget)
        self.rank_Label.setObjectName("rank_Label")
        self.horizontalLayout_2.addWidget(self.rank_Label)
        self.rankValue_Label = QtWidgets.QLabel(self.rankDisplay_Widget)
        self.rankValue_Label.setText("")
        self.rankValue_Label.setObjectName("rankValue_Label")
        self.horizontalLayout_2.addWidget(self.rankValue_Label)
        self.horizontalLayout_2.setStretch(0, 2)
        self.horizontalLayout_2.setStretch(1, 4)
        self.gridLayout_12.addWidget(self.rankDisplay_Widget, 2, 0, 1, 1)
        self.limitedGraph_TabWidget.addTab(self.threshodTab_Widget, "")
        self.tablesTab_Widget = QtWidgets.QWidget()
        self.tablesTab_Widget.setObjectName("tablesTab_Widget")
        self.gridLayout_10 = QtWidgets.QGridLayout(self.tablesTab_Widget)
        self.gridLayout_10.setObjectName("gridLayout_10")
        self.percentageTable_TableWidget = QtWidgets.QTableWidget(self.tablesTab_Widget)
        self.percentageTable_TableWidget.setLineWidth(0)
        self.percentageTable_TableWidget.setObjectName("percentageTable_TableWidget")
        self.percentageTable_TableWidget.setColumnCount(2)
        self.percentageTable_TableWidget.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.percentageTable_TableWidget.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.percentageTable_TableWidget.setHorizontalHeaderItem(1, item)
        self.gridLayout_10.addWidget(self.percentageTable_TableWidget, 0, 0, 1, 1)
        self.nbTable_TableWidget = QtWidgets.QTableWidget(self.tablesTab_Widget)
        self.nbTable_TableWidget.setLineWidth(0)
        self.nbTable_TableWidget.setObjectName("nbTable_TableWidget")
        self.nbTable_TableWidget.setColumnCount(2)
        self.nbTable_TableWidget.setRowCount(0)
        item = QtWidgets.QTableWidgetItem()
        self.nbTable_TableWidget.setHorizontalHeaderItem(0, item)
        item = QtWidgets.QTableWidgetItem()
        self.nbTable_TableWidget.setHorizontalHeaderItem(1, item)
        self.gridLayout_10.addWidget(self.nbTable_TableWidget, 1, 0, 1, 1)
        self.limitedGraph_TabWidget.addTab(self.tablesTab_Widget, "")
        self.gridLayout_2.addWidget(self.limitedGraph_TabWidget, 1, 0, 1, 1)
        self.gridLayout_9.addWidget(self.graphControl_Widget, 0, 1, 1, 1)
        self.graphDisplay_Widget = QtWidgets.QWidget(self.graphSection_Widget)
        self.graphDisplay_Widget.setObjectName("graphDisplay_Widget")
        self.gridLayout_7 = QtWidgets.QGridLayout(self.graphDisplay_Widget)
        self.gridLayout_7.setObjectName("gridLayout_7")
        self.graphDisplay_Layout = QtWidgets.QGridLayout()
        self.graphDisplay_Layout.setSizeConstraint(QtWidgets.QLayout.SetDefaultConstraint)
        self.graphDisplay_Layout.setObjectName("graphDisplay_Layout")
        self.gridLayout_7.addLayout(self.graphDisplay_Layout, 0, 0, 1, 1)
        self.gridLayout_9.addWidget(self.graphDisplay_Widget, 0, 0, 1, 1)
        self.gridLayout_9.setColumnStretch(0, 6)
        self.gridLayout_9.setColumnStretch(1, 2)
        self.gridLayout_9.setRowStretch(0, 1)
        self.gridLayout.addWidget(self.graphSection_Widget, 1, 0, 1, 1)
        self.importFilesSection_Widget = QtWidgets.QWidget(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.importFilesSection_Widget.sizePolicy().hasHeightForWidth())
        self.importFilesSection_Widget.setSizePolicy(sizePolicy)
        self.importFilesSection_Widget.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.importFilesSection_Widget.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.importFilesSection_Widget.setObjectName("importFilesSection_Widget")
        self.gridLayout_6 = QtWidgets.QGridLayout(self.importFilesSection_Widget)
        self.gridLayout_6.setObjectName("gridLayout_6")
        self.importFiles_TabWidget = QtWidgets.QTabWidget(self.importFilesSection_Widget)
        self.importFiles_TabWidget.setMinimumSize(QtCore.QSize(0, 0))
        self.importFiles_TabWidget.setObjectName("importFiles_TabWidget")
        self.filesTab_Widget = QtWidgets.QWidget()
        self.filesTab_Widget.setObjectName("filesTab_Widget")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.filesTab_Widget)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.previousFiltersFiles_Label = QtWidgets.QLabel(self.filesTab_Widget)
        self.previousFiltersFiles_Label.setObjectName("previousFiltersFiles_Label")
        self.gridLayout_4.addWidget(self.previousFiltersFiles_Label, 14, 0, 1, 2)
        self.errorDataNameFile_Label = QtWidgets.QLabel(self.filesTab_Widget)
        self.errorDataNameFile_Label.setText("")
        self.errorDataNameFile_Label.setObjectName("errorDataNameFile_Label")
        self.gridLayout_4.addWidget(self.errorDataNameFile_Label, 2, 0, 1, 2)
        self.previousFlutFiles_List = QtWidgets.QListWidget(self.filesTab_Widget)
        self.previousFlutFiles_List.setMinimumSize(QtCore.QSize(0, 0))
        self.previousFlutFiles_List.setObjectName("previousFlutFiles_List")
        self.gridLayout_4.addWidget(self.previousFlutFiles_List, 10, 0, 1, 2)
        self.openedNameFile_Label = QtWidgets.QLabel(self.filesTab_Widget)
        self.openedNameFile_Label.setMinimumSize(QtCore.QSize(0, 0))
        self.openedNameFile_Label.setAlignment(QtCore.Qt.AlignCenter)
        self.openedNameFile_Label.setObjectName("openedNameFile_Label")
        self.gridLayout_4.addWidget(self.openedNameFile_Label, 1, 0, 1, 1)
        self.openedFlutFile_Label = QtWidgets.QLabel(self.filesTab_Widget)
        self.openedFlutFile_Label.setObjectName("openedFlutFile_Label")
        self.gridLayout_4.addWidget(self.openedFlutFile_Label, 7, 0, 1, 1)
        self.errorFlutFile_Label = QtWidgets.QLabel(self.filesTab_Widget)
        self.errorFlutFile_Label.setText("")
        self.errorFlutFile_Label.setObjectName("errorFlutFile_Label")
        self.gridLayout_4.addWidget(self.errorFlutFile_Label, 8, 0, 1, 2)
        self.importFiltersFile_Button = QtWidgets.QToolButton(self.filesTab_Widget)
        self.importFiltersFile_Button.setText("")
        self.importFiltersFile_Button.setObjectName("importFiltersFile_Button")
        self.gridLayout_4.addWidget(self.importFiltersFile_Button, 12, 1, 1, 1)
        self.importFlutFile_Button = QtWidgets.QToolButton(self.filesTab_Widget)
        self.importFlutFile_Button.setText("")
        self.importFlutFile_Button.setObjectName("importFlutFile_Button")
        self.gridLayout_4.addWidget(self.importFlutFile_Button, 7, 1, 1, 1)
        self.openedFiltersFile_Label = QtWidgets.QLabel(self.filesTab_Widget)
        self.openedFiltersFile_Label.setMinimumSize(QtCore.QSize(0, 0))
        self.openedFiltersFile_Label.setAlignment(QtCore.Qt.AlignCenter)
        self.openedFiltersFile_Label.setObjectName("openedFiltersFile_Label")
        self.gridLayout_4.addWidget(self.openedFiltersFile_Label, 12, 0, 1, 1)
        self.openedDataFile_Label = QtWidgets.QLabel(self.filesTab_Widget)
        self.openedDataFile_Label.setMinimumSize(QtCore.QSize(0, 0))
        self.openedDataFile_Label.setAlignment(QtCore.Qt.AlignCenter)
        self.openedDataFile_Label.setObjectName("openedDataFile_Label")
        self.gridLayout_4.addWidget(self.openedDataFile_Label, 0, 0, 1, 1)
        self.previousDataFiles_Label = QtWidgets.QLabel(self.filesTab_Widget)
        self.previousDataFiles_Label.setMinimumSize(QtCore.QSize(0, 0))
        self.previousDataFiles_Label.setObjectName("previousDataFiles_Label")
        self.gridLayout_4.addWidget(self.previousDataFiles_Label, 4, 0, 1, 2)
        self.importNameFile_Button = QtWidgets.QToolButton(self.filesTab_Widget)
        self.importNameFile_Button.setText("")
        self.importNameFile_Button.setObjectName("importNameFile_Button")
        self.gridLayout_4.addWidget(self.importNameFile_Button, 1, 1, 1, 1)
        spacerItem1 = QtWidgets.QSpacerItem(10, 10, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_4.addItem(spacerItem1, 6, 0, 1, 2)
        spacerItem2 = QtWidgets.QSpacerItem(10, 10, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_4.addItem(spacerItem2, 3, 0, 1, 2)
        self.previousFlutFiles_Label = QtWidgets.QLabel(self.filesTab_Widget)
        self.previousFlutFiles_Label.setMinimumSize(QtCore.QSize(0, 0))
        self.previousFlutFiles_Label.setObjectName("previousFlutFiles_Label")
        self.gridLayout_4.addWidget(self.previousFlutFiles_Label, 9, 0, 1, 2)
        self.importDataFile_Button = QtWidgets.QToolButton(self.filesTab_Widget)
        self.importDataFile_Button.setText("")
        self.importDataFile_Button.setObjectName("importDataFile_Button")
        self.gridLayout_4.addWidget(self.importDataFile_Button, 0, 1, 1, 1)
        spacerItem3 = QtWidgets.QSpacerItem(10, 10, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.gridLayout_4.addItem(spacerItem3, 11, 0, 1, 2)
        self.previousDataFiles_List = QtWidgets.QListWidget(self.filesTab_Widget)
        self.previousDataFiles_List.setMinimumSize(QtCore.QSize(0, 0))
        self.previousDataFiles_List.setObjectName("previousDataFiles_List")
        self.gridLayout_4.addWidget(self.previousDataFiles_List, 5, 0, 1, 2)
        self.errorFiltersFile_Label = QtWidgets.QLabel(self.filesTab_Widget)
        self.errorFiltersFile_Label.setText("")
        self.errorFiltersFile_Label.setObjectName("errorFiltersFile_Label")
        self.gridLayout_4.addWidget(self.errorFiltersFile_Label, 13, 0, 1, 2)
        self.previousFiltersFiles_List = QtWidgets.QListWidget(self.filesTab_Widget)
        self.previousFiltersFiles_List.setMinimumSize(QtCore.QSize(0, 0))
        self.previousFiltersFiles_List.setObjectName("previousFiltersFiles_List")
        self.gridLayout_4.addWidget(self.previousFiltersFiles_List, 15, 0, 1, 2)
        self.gridLayout_4.setRowStretch(0, 5)
        self.gridLayout_4.setRowStretch(1, 5)
        self.gridLayout_4.setRowStretch(2, 5)
        self.gridLayout_4.setRowStretch(3, 1)
        self.gridLayout_4.setRowStretch(4, 5)
        self.gridLayout_4.setRowStretch(5, 60)
        self.gridLayout_4.setRowStretch(6, 1)
        self.gridLayout_4.setRowStretch(7, 5)
        self.gridLayout_4.setRowStretch(8, 5)
        self.gridLayout_4.setRowStretch(9, 5)
        self.gridLayout_4.setRowStretch(10, 35)
        self.gridLayout_4.setRowStretch(11, 1)
        self.gridLayout_4.setRowStretch(12, 5)
        self.gridLayout_4.setRowStretch(13, 5)
        self.gridLayout_4.setRowStretch(14, 5)
        self.gridLayout_4.setRowStretch(15, 35)
        self.importFiles_TabWidget.addTab(self.filesTab_Widget, "")
        self.gridLayout_6.addWidget(self.importFiles_TabWidget, 0, 0, 1, 1)
        self.validationSection_Widget = QtWidgets.QWidget(self.importFilesSection_Widget)
        self.validationSection_Widget.setObjectName("validationSection_Widget")
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout(self.validationSection_Widget)
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.errorValidation_Label = QtWidgets.QLabel(self.validationSection_Widget)
        self.errorValidation_Label.setMinimumSize(QtCore.QSize(0, 0))
        self.errorValidation_Label.setText("")
        self.errorValidation_Label.setObjectName("errorValidation_Label")
        self.horizontalLayout_5.addWidget(self.errorValidation_Label)
        self.validation_Button = QtWidgets.QToolButton(self.validationSection_Widget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.validation_Button.sizePolicy().hasHeightForWidth())
        self.validation_Button.setSizePolicy(sizePolicy)
        self.validation_Button.setMinimumSize(QtCore.QSize(0, 0))
        self.validation_Button.setObjectName("validation_Button")
        self.horizontalLayout_5.addWidget(self.validation_Button)
        self.horizontalLayout_5.setStretch(0, 4)
        self.gridLayout_6.addWidget(self.validationSection_Widget, 1, 0, 1, 1)
        self.gridLayout_6.setRowStretch(0, 95)
        self.gridLayout_6.setRowStretch(1, 5)
        self.gridLayout.addWidget(self.importFilesSection_Widget, 0, 1, 2, 1)
        self.informationsSection_Widget = QtWidgets.QWidget(self.centralwidget)
        self.informationsSection_Widget.setContextMenuPolicy(QtCore.Qt.NoContextMenu)
        self.informationsSection_Widget.setObjectName("informationsSection_Widget")
        self.gridLayout_8 = QtWidgets.QGridLayout(self.informationsSection_Widget)
        self.gridLayout_8.setObjectName("gridLayout_8")
        self.openedFiles_Widget = QtWidgets.QWidget(self.informationsSection_Widget)
        self.openedFiles_Widget.setMinimumSize(QtCore.QSize(0, 0))
        self.openedFiles_Widget.setObjectName("openedFiles_Widget")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.openedFiles_Widget)
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.openedCurrentFiles_Label = QtWidgets.QLabel(self.openedFiles_Widget)
        self.openedCurrentFiles_Label.setMinimumSize(QtCore.QSize(0, 0))
        self.openedCurrentFiles_Label.setObjectName("openedCurrentFiles_Label")
        self.horizontalLayout.addWidget(self.openedCurrentFiles_Label)
        self.openedCurrentDataFile_Label = QtWidgets.QLabel(self.openedFiles_Widget)
        self.openedCurrentDataFile_Label.setMinimumSize(QtCore.QSize(0, 0))
        self.openedCurrentDataFile_Label.setObjectName("openedCurrentDataFile_Label")
        self.horizontalLayout.addWidget(self.openedCurrentDataFile_Label)
        self.currentDataFile_Label = QtWidgets.QLabel(self.openedFiles_Widget)
        self.currentDataFile_Label.setMinimumSize(QtCore.QSize(0, 0))
        self.currentDataFile_Label.setText("")
        self.currentDataFile_Label.setObjectName("currentDataFile_Label")
        self.horizontalLayout.addWidget(self.currentDataFile_Label)
        self.openedCurrentFlutFile_Label = QtWidgets.QLabel(self.openedFiles_Widget)
        self.openedCurrentFlutFile_Label.setMinimumSize(QtCore.QSize(0, 0))
        self.openedCurrentFlutFile_Label.setObjectName("openedCurrentFlutFile_Label")
        self.horizontalLayout.addWidget(self.openedCurrentFlutFile_Label)
        self.currentFlutFile_Label = QtWidgets.QLabel(self.openedFiles_Widget)
        self.currentFlutFile_Label.setMinimumSize(QtCore.QSize(0, 0))
        self.currentFlutFile_Label.setText("")
        self.currentFlutFile_Label.setObjectName("currentFlutFile_Label")
        self.horizontalLayout.addWidget(self.currentFlutFile_Label)
        self.horizontalLayout.setStretch(0, 2)
        self.horizontalLayout.setStretch(1, 1)
        self.horizontalLayout.setStretch(2, 4)
        self.horizontalLayout.setStretch(3, 1)
        self.horizontalLayout.setStretch(4, 4)
        self.gridLayout_8.addWidget(self.openedFiles_Widget, 0, 0, 1, 1)
        self.fileInformations_Widget = QtWidgets.QWidget(self.informationsSection_Widget)
        self.fileInformations_Widget.setObjectName("fileInformations_Widget")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.fileInformations_Widget)
        self.gridLayout_3.setSizeConstraint(QtWidgets.QLayout.SetDefaultConstraint)
        self.gridLayout_3.setContentsMargins(0, 0, 0, 0)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.nbConnections_Label = QtWidgets.QLabel(self.fileInformations_Widget)
        self.nbConnections_Label.setMinimumSize(QtCore.QSize(0, 0))
        self.nbConnections_Label.setObjectName("nbConnections_Label")
        self.gridLayout_3.addWidget(self.nbConnections_Label, 1, 0, 1, 1)
        self.nbNodes_Label = QtWidgets.QLabel(self.fileInformations_Widget)
        self.nbNodes_Label.setMinimumSize(QtCore.QSize(0, 0))
        self.nbNodes_Label.setObjectName("nbNodes_Label")
        self.gridLayout_3.addWidget(self.nbNodes_Label, 0, 0, 1, 1)
        self.nbNodesValue_Label = QtWidgets.QLabel(self.fileInformations_Widget)
        self.nbNodesValue_Label.setMinimumSize(QtCore.QSize(0, 0))
        self.nbNodesValue_Label.setText("")
        self.nbNodesValue_Label.setObjectName("nbNodesValue_Label")
        self.gridLayout_3.addWidget(self.nbNodesValue_Label, 0, 2, 1, 1)
        self.sumAbsValue_Label = QtWidgets.QLabel(self.fileInformations_Widget)
        self.sumAbsValue_Label.setMinimumSize(QtCore.QSize(0, 0))
        self.sumAbsValue_Label.setText("")
        self.sumAbsValue_Label.setObjectName("sumAbsValue_Label")
        self.gridLayout_3.addWidget(self.sumAbsValue_Label, 0, 4, 1, 1)
        self.max_Label = QtWidgets.QLabel(self.fileInformations_Widget)
        self.max_Label.setMinimumSize(QtCore.QSize(0, 0))
        self.max_Label.setObjectName("max_Label")
        self.gridLayout_3.addWidget(self.max_Label, 0, 5, 1, 1)
        self.standardDeviation_Label = QtWidgets.QLabel(self.fileInformations_Widget)
        self.standardDeviation_Label.setMinimumSize(QtCore.QSize(0, 0))
        self.standardDeviation_Label.setObjectName("standardDeviation_Label")
        self.gridLayout_3.addWidget(self.standardDeviation_Label, 0, 7, 1, 1)
        self.sumAbs_Label = QtWidgets.QLabel(self.fileInformations_Widget)
        self.sumAbs_Label.setMinimumSize(QtCore.QSize(0, 0))
        self.sumAbs_Label.setObjectName("sumAbs_Label")
        self.gridLayout_3.addWidget(self.sumAbs_Label, 0, 3, 1, 1)
        self.standardDeviationValue_Label = QtWidgets.QLabel(self.fileInformations_Widget)
        self.standardDeviationValue_Label.setMinimumSize(QtCore.QSize(0, 0))
        self.standardDeviationValue_Label.setText("")
        self.standardDeviationValue_Label.setObjectName("standardDeviationValue_Label")
        self.gridLayout_3.addWidget(self.standardDeviationValue_Label, 0, 8, 1, 1)
        self.maxValue_Label = QtWidgets.QLabel(self.fileInformations_Widget)
        self.maxValue_Label.setMinimumSize(QtCore.QSize(0, 0))
        self.maxValue_Label.setText("")
        self.maxValue_Label.setObjectName("maxValue_Label")
        self.gridLayout_3.addWidget(self.maxValue_Label, 0, 6, 1, 1)
        self.nbConnectionsValue_Label = QtWidgets.QLabel(self.fileInformations_Widget)
        self.nbConnectionsValue_Label.setMinimumSize(QtCore.QSize(0, 0))
        self.nbConnectionsValue_Label.setText("")
        self.nbConnectionsValue_Label.setObjectName("nbConnectionsValue_Label")
        self.gridLayout_3.addWidget(self.nbConnectionsValue_Label, 1, 2, 1, 1)
        self.meanAbs_Label = QtWidgets.QLabel(self.fileInformations_Widget)
        self.meanAbs_Label.setMinimumSize(QtCore.QSize(0, 0))
        self.meanAbs_Label.setObjectName("meanAbs_Label")
        self.gridLayout_3.addWidget(self.meanAbs_Label, 1, 3, 1, 1)
        self.meanAbsValue_Label = QtWidgets.QLabel(self.fileInformations_Widget)
        self.meanAbsValue_Label.setMinimumSize(QtCore.QSize(0, 0))
        self.meanAbsValue_Label.setText("")
        self.meanAbsValue_Label.setObjectName("meanAbsValue_Label")
        self.gridLayout_3.addWidget(self.meanAbsValue_Label, 1, 4, 1, 1)
        self.otherValueValue_Label = QtWidgets.QLabel(self.fileInformations_Widget)
        self.otherValueValue_Label.setText("")
        self.otherValueValue_Label.setObjectName("otherValueValue_Label")
        self.gridLayout_3.addWidget(self.otherValueValue_Label, 1, 8, 1, 1)
        self.otherValue_Label = QtWidgets.QLabel(self.fileInformations_Widget)
        self.otherValue_Label.setText("")
        self.otherValue_Label.setObjectName("otherValue_Label")
        self.gridLayout_3.addWidget(self.otherValue_Label, 1, 7, 1, 1)
        self.minValue_Label = QtWidgets.QLabel(self.fileInformations_Widget)
        self.minValue_Label.setMinimumSize(QtCore.QSize(0, 0))
        self.minValue_Label.setText("")
        self.minValue_Label.setObjectName("minValue_Label")
        self.gridLayout_3.addWidget(self.minValue_Label, 1, 6, 1, 1)
        self.min_Label = QtWidgets.QLabel(self.fileInformations_Widget)
        self.min_Label.setMinimumSize(QtCore.QSize(0, 0))
        self.min_Label.setObjectName("min_Label")
        self.gridLayout_3.addWidget(self.min_Label, 1, 5, 1, 1)
        self.gridLayout_8.addWidget(self.fileInformations_Widget, 1, 0, 1, 1)
        self.gridLayout_8.setRowStretch(0, 1)
        self.gridLayout_8.setRowStretch(1, 2)
        self.gridLayout.addWidget(self.informationsSection_Widget, 0, 0, 1, 1)
        self.gridLayout.setColumnStretch(0, 4)
        self.gridLayout.setColumnStretch(1, 1)
        self.gridLayout.setRowStretch(0, 1)
        self.gridLayout.setRowStretch(1, 4)
        ImportWindow.setCentralWidget(self.centralwidget)

        self.retranslateUi(ImportWindow)
        self.limitedGraph_TabWidget.setCurrentIndex(0)
        self.importFiles_TabWidget.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(ImportWindow)

    def retranslateUi(self, ImportWindow):
        _translate = QtCore.QCoreApplication.translate
        ImportWindow.setWindowTitle(_translate("ImportWindow", "ImportWindow"))
        self.limitedGraph_TabWidget.setProperty("class", _translate("ImportWindow", "whiteGrayTabWidget"))
        self.minSlider_Label.setText(_translate("ImportWindow", "Min :"))
        self.minSlider_Label.setProperty("class", _translate("ImportWindow", "standardLabel"))
        self.maxSlider_Label.setText(_translate("ImportWindow", "Max :"))
        self.maxSlider_Label.setProperty("class", _translate("ImportWindow", "standardLabel"))
        self.threshold_Label.setText(_translate("ImportWindow", "Threshold :"))
        self.threshold_Label.setProperty("class", _translate("ImportWindow", "infoLabel"))
        self.rank_Label.setText(_translate("ImportWindow", "Rank :"))
        self.rank_Label.setProperty("class", _translate("ImportWindow", "infoLabel"))
        self.rankValue_Label.setProperty("class", _translate("ImportWindow", "valueLabel"))
        self.limitedGraph_TabWidget.setTabText(self.limitedGraph_TabWidget.indexOf(self.threshodTab_Widget), _translate("ImportWindow", "Threshold"))
        self.percentageTable_TableWidget.setProperty("class", _translate("ImportWindow", "infoTable"))
        item = self.percentageTable_TableWidget.horizontalHeaderItem(0)
        item.setText(_translate("ImportWindow", "Percentage"))
        item = self.percentageTable_TableWidget.horizontalHeaderItem(1)
        item.setText(_translate("ImportWindow", "ABS Mean"))
        self.nbTable_TableWidget.setProperty("class", _translate("ImportWindow", "infoTable"))
        item = self.nbTable_TableWidget.horizontalHeaderItem(0)
        item.setText(_translate("ImportWindow", "Rank"))
        item = self.nbTable_TableWidget.horizontalHeaderItem(1)
        item.setText(_translate("ImportWindow", "ABS Mean"))
        self.limitedGraph_TabWidget.setTabText(self.limitedGraph_TabWidget.indexOf(self.tablesTab_Widget), _translate("ImportWindow", "Table"))
        self.importFiles_TabWidget.setProperty("class", _translate("ImportWindow", "whiteGrayTabWidget"))
        self.previousFiltersFiles_Label.setText(_translate("ImportWindow", "Previous Filters File Opened :"))
        self.previousFiltersFiles_Label.setProperty("class", _translate("ImportWindow", "standardLabel"))
        self.errorDataNameFile_Label.setProperty("class", _translate("ImportWindow", "errorLabel"))
        self.previousFlutFiles_List.setProperty("class", _translate("ImportWindow", "blackListWidget"))
        self.openedNameFile_Label.setText(_translate("ImportWindow", "No Name File Opened"))
        self.openedNameFile_Label.setProperty("class", _translate("ImportWindow", "standardLabel"))
        self.openedFlutFile_Label.setText(_translate("ImportWindow", "No Flut File Opened"))
        self.openedFlutFile_Label.setProperty("class", _translate("ImportWindow", "standardLabel"))
        self.errorFlutFile_Label.setProperty("class", _translate("ImportWindow", "errorLabel"))
        self.importFiltersFile_Button.setProperty("class", _translate("ImportWindow", "whiteBGButton"))
        self.importFlutFile_Button.setProperty("class", _translate("ImportWindow", "whiteBGButton"))
        self.openedFiltersFile_Label.setText(_translate("ImportWindow", "No Filters File Opened (Optional File)"))
        self.openedFiltersFile_Label.setProperty("class", _translate("ImportWindow", "standardLabel"))
        self.openedDataFile_Label.setText(_translate("ImportWindow", "No File Opened"))
        self.openedDataFile_Label.setProperty("class", _translate("ImportWindow", "standardLabel"))
        self.previousDataFiles_Label.setText(_translate("ImportWindow", "Previous Data File Opened :"))
        self.previousDataFiles_Label.setProperty("class", _translate("ImportWindow", "standardLabel"))
        self.importNameFile_Button.setProperty("class", _translate("ImportWindow", "whiteBGButton"))
        self.previousFlutFiles_Label.setText(_translate("ImportWindow", "Previous FLUT File Opened :"))
        self.previousFlutFiles_Label.setProperty("class", _translate("ImportWindow", "standardLabel"))
        self.importDataFile_Button.setProperty("class", _translate("ImportWindow", "whiteBGButton"))
        self.previousDataFiles_List.setProperty("class", _translate("ImportWindow", "blackListWidget"))
        self.errorFiltersFile_Label.setProperty("class", _translate("ImportWindow", "errorLabel"))
        self.previousFiltersFiles_List.setProperty("class", _translate("ImportWindow", "blackListWidget"))
        self.importFiles_TabWidget.setTabText(self.importFiles_TabWidget.indexOf(self.filesTab_Widget), _translate("ImportWindow", "Files Part"))
        self.errorValidation_Label.setProperty("class", _translate("ImportWindow", "errorLabel"))
        self.validation_Button.setText(_translate("ImportWindow", "Validation"))
        self.validation_Button.setProperty("class", _translate("ImportWindow", "grayRoundedButton"))
        self.openedCurrentFiles_Label.setText(_translate("ImportWindow", "File Opened\n"
"(Data / FLUT)"))
        self.openedCurrentFiles_Label.setProperty("class", _translate("ImportWindow", "standardLabel"))
        self.openedCurrentDataFile_Label.setText(_translate("ImportWindow", "Data File :"))
        self.openedCurrentDataFile_Label.setProperty("class", _translate("ImportWindow", "infoLabel"))
        self.currentDataFile_Label.setProperty("class", _translate("ImportWindow", "valueLabel"))
        self.openedCurrentFlutFile_Label.setText(_translate("ImportWindow", "FLUT File :"))
        self.openedCurrentFlutFile_Label.setProperty("class", _translate("ImportWindow", "infoLabel"))
        self.currentFlutFile_Label.setProperty("class", _translate("ImportWindow", "valueLabel"))
        self.nbConnections_Label.setText(_translate("ImportWindow", "Number of Connections :"))
        self.nbConnections_Label.setProperty("class", _translate("ImportWindow", "infoLabel"))
        self.nbNodes_Label.setText(_translate("ImportWindow", "Number of Nodes :"))
        self.nbNodes_Label.setProperty("class", _translate("ImportWindow", "infoLabel"))
        self.nbNodesValue_Label.setProperty("class", _translate("ImportWindow", "valueLabel"))
        self.sumAbsValue_Label.setProperty("class", _translate("ImportWindow", "valueLabel"))
        self.max_Label.setText(_translate("ImportWindow", "Max :"))
        self.max_Label.setProperty("class", _translate("ImportWindow", "infoLabel"))
        self.standardDeviation_Label.setText(_translate("ImportWindow", "Standard\n"
"Deviation"))
        self.standardDeviation_Label.setProperty("class", _translate("ImportWindow", "infoLabel"))
        self.sumAbs_Label.setText(_translate("ImportWindow", "Sum (ABS) :"))
        self.sumAbs_Label.setProperty("class", _translate("ImportWindow", "infoLabel"))
        self.standardDeviationValue_Label.setProperty("class", _translate("ImportWindow", "valueLabel"))
        self.maxValue_Label.setProperty("class", _translate("ImportWindow", "valueLabel"))
        self.nbConnectionsValue_Label.setProperty("class", _translate("ImportWindow", "valueLabel"))
        self.meanAbs_Label.setText(_translate("ImportWindow", "Mean (ABS) :"))
        self.meanAbs_Label.setProperty("class", _translate("ImportWindow", "infoLabel"))
        self.meanAbsValue_Label.setProperty("class", _translate("ImportWindow", "valueLabel"))
        self.minValue_Label.setProperty("class", _translate("ImportWindow", "valueLabel"))
        self.min_Label.setText(_translate("ImportWindow", "Min :"))
        self.min_Label.setProperty("class", _translate("ImportWindow", "infoLabel"))
